import logging
import typing
import re

from aiogram.client.session import aiohttp


def split_text(text: str, length: int = 4096) -> typing.List[str]:
    """
    Split long text

    :param text:
    :param length:
    :return: list of parts
    :rtype: :obj:`typing.List[str]`
    """
    return [text[i:i + length] for i in range(0, len(text), length)]


def remove_text_in_brackets_and_parentheses(text):
    return re.sub("[\(\[].*?[\)\]]", "", text)


def split_text_by_sentences(text, max_length):
    # Split the text into sentences by looking for periods followed by spaces, assuming this as a basic criteria for end of a sentence.
    sentences = text.split('. ')
    chunks = []
    current_chunk = ""

    for sentence in sentences:
        # Adding 2 accounts for the period and space we split on, except for the last sentence which might not need it
        if len(current_chunk) + len(sentence) + 2 <= max_length:
            current_chunk += sentence + ". "
        else:
            # If the current chunk + the next sentence exceeds max length, store the current chunk and start a new one.
            chunks.append(current_chunk.strip())
            current_chunk = sentence + ". "

    # Add the last chunk if it's not empty, trimming the extra space and period added at the end
    if current_chunk:
        chunks.append(current_chunk.strip())

    return chunks


def split_text_into_chunks_by_sentences(text, sentences_per_chunk=2):
    # Split the text into sentences by looking for periods followed by spaces, assuming this as a basic criteria for end of a sentence.
    sentences = text.split('. ')
    chunks = []
    current_chunk = []
    sentences_count = 0

    for sentence in sentences:
        # Add the sentence to the current chunk
        current_chunk.append(sentence)
        sentences_count += 1
        # Check if the current chunk has the required number of sentences
        if sentences_count == sentences_per_chunk:
            # Join the sentences to form a chunk and add it to the chunks list
            chunks.append('. '.join(current_chunk))
            current_chunk = []
            sentences_count = 0

    # Check for any remaining sentences that didn't form a complete chunk
    if current_chunk:
        chunks.append('. '.join(current_chunk))

    return chunks


async def get_website_html(url: str):
    async with aiohttp.ClientSession() as session:
        async with session.get(url) as response:
            html = await response.text(encoding=response.charset)
    return html


async def get_website_as_text(url: str):
    to_reader_url = "https://toolsyep.com/en/webpage-to-plain-text/"
    async with aiohttp.ClientSession() as session:
        async with session.get(to_reader_url, params={
            "u": url
        }) as response:
            html = await response.text(encoding=response.charset)
    return html
